package com.ims.eval.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ims.common.utils.StringUtils;
import com.ims.eval.config.CustomException;
import com.ims.eval.entity.EvaluationDept;
import com.ims.eval.entity.EvaluationDeptBusinessAssessment;
import com.ims.eval.entity.EvaluationDeptBusinessContent;
import com.ims.eval.entity.custom.Path;
import com.ims.eval.entity.dto.request.DeptDTO;
import com.ims.eval.entity.dto.request.EvaluationDeptBusinessAssessmentDTO;
import com.ims.eval.entity.dto.result.R;
import com.ims.eval.service.IEvaluationDeptBusinessAssessmentService;
import com.ims.eval.service.IEvaluationDeptBusinessContentService;
import com.ims.eval.service.IEvaluationDeptService;
import com.ims.eval.util.ExcelUtil;
import com.ims.eval.util.WordUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 本部部门业绩指标考核
 *
 * @author hlf
 * @date 2023/4/28 10:09
 * 文件说明：
 */
@Slf4j
@RestController
@RequestMapping("//evaluation-dept-assessment")
public class DepartmentalPerformanceIndicatorAssessmentController {

	@Autowired
	private IEvaluationDeptBusinessAssessmentService evaluationDeptBusinessAssessmentService;

	@Autowired
	private IEvaluationDeptBusinessContentService evaluationDeptBusinessContentService;

	@Autowired
	private IEvaluationDeptService evaluationDeptService;

	@Autowired
	private HttpServletRequest request;

	/**
	 * 部门考评业务列表信息（分页）
	 *
	 * @param pageNum            当前记录起始索引
	 * @param pageSize           每页显示记录数
	 * @param responsibilityCode 业务编码
	 * @param des                业务简述
	 * @param appraisalYear      月度
	 * @param stage              流程状态
	 * @return 结果
	 */
	@GetMapping(value = "/list")
	public R list(
		@RequestParam(value = "pageNum") Integer pageNum,
		@RequestParam(value = "pageSize") Integer pageSize,
		@RequestParam(value = "deptId") String deptId,
		@RequestParam(value = "responsibilityCode", required = false) String responsibilityCode,
		@RequestParam(value = "des", required = false) String des,
		@RequestParam(value = "appraisalYear", required = false) String appraisalYear,
		@RequestParam(value = "stage", required = false) String stage) {
		IPage<EvaluationDeptBusinessAssessment> list = evaluationDeptBusinessAssessmentService.listPage(pageNum, pageSize, deptId, responsibilityCode, des, appraisalYear, stage, request);
		return R.ok().data(list);
	}

	/**
	 * 部门考评业务信息
	 *
	 * @return 结果
	 */
	@GetMapping(value = "/listAll")
	public R listAll() {
		List<EvaluationDeptBusinessAssessment> list = evaluationDeptBusinessAssessmentService.list();
		return R.ok().data(list);
	}

	/**
	 * 生成报表
	 *
	 * @return 结果
	 */
	@GetMapping(value = "/generateReport/{id}")
	public R generateReport(@PathVariable("id") String id) throws Exception {
		Map<String, Object> dataMap = new HashMap<>();
		List<DeptDTO> deptList = new ArrayList<>();
		String fileName;
		EvaluationDeptBusinessAssessment evaluationDeptBusinessAssessment = evaluationDeptBusinessAssessmentService.getById(id);
		if (null == evaluationDeptBusinessAssessment.getDeptId() && null == evaluationDeptBusinessAssessment.getDeptName()) {
			QueryWrapper<EvaluationDept> qw = new QueryWrapper<>();
			qw.lambda().eq(EvaluationDept::getYjzbjhType, "1");
			qw.lambda().orderByAsc(EvaluationDept::getSerialNumber);
			List<EvaluationDept> evaluationDeptList = evaluationDeptService.list(qw);
			for (EvaluationDept evaluationDept : evaluationDeptList) {
				DeptDTO dept = new DeptDTO();
				dept.setDeptId(evaluationDept.getDeptId());
				dept.setDeptName(evaluationDept.getDeptName());
				List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = evaluationDeptBusinessContentService.selectEvaluationDeptBusinessContentListByBusinessPlanId(id, evaluationDept.getDeptId());
				dept.setList(evaluationDeptBusinessContentList);
				deptList.add(dept);
			}
			fileName = evaluationDeptBusinessAssessment.getAppraisalYear() + "年度经营业绩完成情况.doc";
		} else {
			DeptDTO dept = new DeptDTO();
			dept.setDeptId(evaluationDeptBusinessAssessment.getDeptId());
			dept.setDeptName(evaluationDeptBusinessAssessment.getDeptName());
			List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = evaluationDeptBusinessContentService.selectEvaluationDeptBusinessContentListByBusinessPlanId(id, evaluationDeptBusinessAssessment.getDeptId());
			dept.setList(evaluationDeptBusinessContentList);
			deptList.add(dept);
			fileName = evaluationDeptBusinessAssessment.getDeptName() + evaluationDeptBusinessAssessment.getAppraisalYear() + "年度经营业绩完成情况.doc";
		}
		dataMap.put("appraisalYear", evaluationDeptBusinessAssessment.getAppraisalYear());
		dataMap.put("list", deptList);
		WordUtil.generateWord(dataMap, "template_dbkp_wcqk.ftl", Path.getStatementPath(), fileName);
		return R.ok().data(fileName);
	}

	/**
	 * 统计汇总数据
	 *
	 * @param year 年度
	 */
	@GetMapping(value = "/statisticalSummary")
	public R statisticalSummary(@RequestParam(value = "year") String year) {
		Map<String, List<EvaluationDeptBusinessAssessmentDTO>> map = new HashMap<>();
		List<EvaluationDeptBusinessAssessment> evaluationDeptBusinessAssessmentList = evaluationDeptBusinessAssessmentService.selectEvaluationDeptBusinessAssessmentByYear(year);
		if ("2023".equals(year)) {
			QueryWrapper<EvaluationDept> qw = new QueryWrapper<>();
			qw.lambda().eq(EvaluationDept::getYjzbjhType, "1");
			qw.lambda().orderByAsc(EvaluationDept::getSerialNumber);
			List<EvaluationDept> evaluationDeptList = evaluationDeptService.list(qw);
			for (EvaluationDept evaluationDept : evaluationDeptList) {
				if (evaluationDeptBusinessAssessmentList.size() > 0) {
					List<EvaluationDeptBusinessAssessmentDTO> dtoList = new ArrayList<>();
					List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = evaluationDeptBusinessContentService.selectEvaluationDeptBusinessContentListByBusinessPlanId(evaluationDeptBusinessAssessmentList.get(0).getId(), evaluationDept.getDeptId());
					for (EvaluationDeptBusinessContent evaluationDeptBusinessContent : evaluationDeptBusinessContentList) {
						EvaluationDeptBusinessAssessmentDTO dto = new EvaluationDeptBusinessAssessmentDTO();
						dto.setSerialNumber(evaluationDeptBusinessContent.getSerialNumber());
						dto.setTargetName(evaluationDeptBusinessContent.getTargetName());
						dto.setTargetValue(evaluationDeptBusinessContent.getTargetValue());
						dto.setBaseScore(evaluationDeptBusinessContent.getBaseScore());
						dto.setCompletionStatus(evaluationDeptBusinessContent.getCompletionStatus());
						dto.setEvaluationCriteria(evaluationDeptBusinessContent.getEvaluationCriteria());
						dto.setEvaluationScore(evaluationDeptBusinessContent.getEvaluationScore());
						dtoList.add(dto);
					}
					map.put(evaluationDept.getDeptName(), dtoList);
				}
			}
		} else {
			for (EvaluationDeptBusinessAssessment evaluationDeptBusinessAssessment : evaluationDeptBusinessAssessmentList) {
				List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = evaluationDeptBusinessContentService.selectEvaluationDeptBusinessContentListByBusinessPlanId(evaluationDeptBusinessAssessment.getId(), evaluationDeptBusinessAssessment.getDeptId());
				List<EvaluationDeptBusinessAssessmentDTO> dtoList = new ArrayList<>();
				for (EvaluationDeptBusinessContent evaluationDeptBusinessContent : evaluationDeptBusinessContentList) {
					EvaluationDeptBusinessAssessmentDTO dto = new EvaluationDeptBusinessAssessmentDTO();
					dto.setSerialNumber(evaluationDeptBusinessContent.getSerialNumber());
					dto.setTargetName(evaluationDeptBusinessContent.getTargetName());
					dto.setTargetValue(evaluationDeptBusinessContent.getTargetValue());
					dto.setBaseScore(evaluationDeptBusinessContent.getBaseScore());
					dto.setCompletionStatus(evaluationDeptBusinessContent.getCompletionStatus());
					dto.setEvaluationCriteria(evaluationDeptBusinessContent.getEvaluationCriteria());
					dto.setEvaluationScore(evaluationDeptBusinessContent.getEvaluationScore());
					dtoList.add(dto);
				}
				map.put(evaluationDeptBusinessAssessment.getDeptName(), dtoList);
			}
		}
		return R.ok().data(map);
	}

	/**
	 * 生成汇总报表
	 *
	 * @return 结果
	 */
	@GetMapping(value = "/summaryReport/{year}")
	public R summaryReport(@PathVariable("year") String year) throws Exception {
		Map<String, Object> dataMap = new HashMap<>();
		List<EvaluationDeptBusinessAssessment> evaluationDeptBusinessAssessmentList = evaluationDeptBusinessAssessmentService.selectEvaluationDeptBusinessAssessmentByYear(year);
		List<DeptDTO> deptList = new ArrayList<>();
		if ("2023".equals(year)) {
			QueryWrapper<EvaluationDept> qw = new QueryWrapper<>();
			qw.lambda().eq(EvaluationDept::getYjzbjhType, "1");
			qw.lambda().orderByAsc(EvaluationDept::getSerialNumber);
			List<EvaluationDept> evaluationDeptList = evaluationDeptService.list(qw);
			for (EvaluationDept evaluationDept : evaluationDeptList) {
				if (evaluationDeptBusinessAssessmentList.size() > 0) {
					DeptDTO dept = new DeptDTO();
					dept.setDeptId(evaluationDept.getDeptId());
					dept.setDeptName(evaluationDept.getDeptName());
					List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = evaluationDeptBusinessContentService.selectEvaluationDeptBusinessContentListByBusinessPlanId(evaluationDeptBusinessAssessmentList.get(0).getId(), evaluationDept.getDeptId());
					dept.setList(evaluationDeptBusinessContentList);
					deptList.add(dept);
				}
			}
		} else {
			for (EvaluationDeptBusinessAssessment evaluationDeptBusinessAssessment : evaluationDeptBusinessAssessmentList) {
				DeptDTO dept = new DeptDTO();
				dept.setDeptId(evaluationDeptBusinessAssessment.getDeptId());
				dept.setDeptName(evaluationDeptBusinessAssessment.getDeptName());
				List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = evaluationDeptBusinessContentService.selectEvaluationDeptBusinessContentListByBusinessPlanId(evaluationDeptBusinessAssessment.getId(), evaluationDeptBusinessAssessment.getDeptId());
				dept.setList(evaluationDeptBusinessContentList);
				deptList.add(dept);
			}
		}
		dataMap.put("appraisalYear", year);
		dataMap.put("list", deptList);
		String fileName = year + "年度经营业绩完成情况.doc";
		WordUtil.generateWord(dataMap, "template_dbkp_wcqk.ftl", Path.getStatementPath(), fileName);
		return R.ok().data(fileName);
	}

	/**
	 * 下载报表
	 *
	 * @param request    request
	 * @param response   response
	 * @param reportName 文件名
	 * @throws IOException 异常
	 */
	@GetMapping(value = "/downloadReport/{reportName}")
	public void downloadReport(HttpServletRequest request, HttpServletResponse response, @PathVariable("reportName") String reportName) throws IOException {
		//设置文件路径
		File file = new File(Path.getStatementPath() + reportName);
		//判断文件是否存在
		if (file.exists()) {
			//设置强制下载不打开
			response.setContentType("application/force-download");
			//设置文件名
			response.addHeader("Content-Disposition", "attachment;fileName=".concat(String.valueOf(URLEncoder.encode(reportName, "UTF-8"))));
			byte[] buffer = new byte[1024];
			FileInputStream fis = null;
			BufferedInputStream bis = null;
			try {
				fis = new FileInputStream(file);
				bis = new BufferedInputStream(fis);
				OutputStream os = response.getOutputStream();
				int i = bis.read(buffer);
				while (i != -1) {
					os.write(buffer, 0, i);
					i = bis.read(buffer);
				}
			} catch (Exception e) {
				e.printStackTrace();
			} finally {
				if (bis != null) {
					try {
						bis.close();
					} catch (IOException e) {
						e.printStackTrace();
					}
				}
				if (fis != null) {
					try {
						fis.close();
					} catch (IOException e) {
						e.printStackTrace();
					}
				}
			}
		}
	}

	/**
	 * 修改状态
	 *
	 * @param id    主键
	 * @param stage 状态
	 * @return 结果
	 */
	@PostMapping(value = "/targetStart")
	public R targetStart(@RequestParam(value = "id") String id,
						 @RequestParam(value = "stage") String stage) {
		try {
			EvaluationDeptBusinessAssessment evaluationDeptBusinessAssessment = evaluationDeptBusinessAssessmentService.getById(id);
			evaluationDeptBusinessAssessment.setStage(stage);
			boolean b = evaluationDeptBusinessAssessmentService.updateById(evaluationDeptBusinessAssessment);
			if (b) {
				return R.ok().data(b);
			} else {
				return R.error("失败！");
			}
		} catch (CustomException e) {
			return R.customError(e.getMessage()).data("失败！");
		}
	}

	/**
	 * 详情-头部信息
	 *
	 * @param id 业务主键
	 * @return 结果
	 */
	@GetMapping(value = "/detailsHead/{id}")
	public R detailsHead(@PathVariable("id") String id) {
		EvaluationDeptBusinessAssessment evaluationDeptBusinessAssessment = evaluationDeptBusinessAssessmentService.getById(id);
		return R.ok().data(evaluationDeptBusinessAssessment);
	}

	/**
	 * 导入
	 *
	 * @param file 文件
	 * @return 结果
	 */
	@PostMapping(value = "/import")
	public R importData(@RequestParam("file") MultipartFile file, @RequestParam("id") String id) {
		if (!file.isEmpty()) {
			try {
				//获取原始的文件名
				String originalFilename = file.getOriginalFilename();
				//获取文件类型
				String fileType = originalFilename.substring(originalFilename.lastIndexOf(".") + 1, originalFilename.length());
				//默认从第一行开始读取
				int startRows = 1;
				//获取输入流
				InputStream is = file.getInputStream();
				List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = new ArrayList<>();
				//Excel导入导出的单元类
				List<String[]> strings = ExcelUtil.readData(fileType, startRows, true, is);
				//遍历Excel表每一行的数据
				for (String[] str : strings) {
					EvaluationDeptBusinessContent evaluationDeptBusinessContent = new EvaluationDeptBusinessContent();
					evaluationDeptBusinessContent.setBusinessPlanId(id);
					evaluationDeptBusinessContent.setTargetName(str[3]);
					evaluationDeptBusinessContent.setCompletionStatus(str[6]);
					evaluationDeptBusinessContent.setEvaluationScore(str[8]);
					evaluationDeptBusinessContentList.add(evaluationDeptBusinessContent);
				}
				boolean b = evaluationDeptBusinessContentService.importAssessmentDataList(evaluationDeptBusinessContentList);
				if (b) {
					return R.ok().data(b);
				} else {
					return R.error("导入失败！");
				}
			} catch (Exception e) {
				log.error("错误", e);
				return R.customError(e.getMessage()).data("失败！");
			}
		}
		return R.error("上传文件为空！");
	}

	/**
	 * 校验审核状态
	 *
	 * @param id 主键
	 * @return 结果
	 */
	@GetMapping(value = "/checkAuditStatus/{id}/{deptId}")
	public R checkAuditStatus(@PathVariable String id, @PathVariable String deptId) {
		boolean b = true;
		String msg = "";
		QueryWrapper<EvaluationDeptBusinessContent> qw = new QueryWrapper<>();
		if (StringUtils.isNotEmpty(id)) {
			qw.lambda().eq(EvaluationDeptBusinessContent::getBusinessPlanId, id);
		}
		List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = evaluationDeptBusinessContentService.list(qw);
		if ("23031009".equals(deptId)) {//组织人事部
			for (EvaluationDeptBusinessContent evaluationDeptBusinessContent : evaluationDeptBusinessContentList) {
				if (!"0".equals(evaluationDeptBusinessContent.getAuditStatusKp())) {
					b = false;
					msg = "数据审核状态未通过！";
					break;
				}
			}
		} else {
			for (EvaluationDeptBusinessContent evaluationDeptBusinessContent : evaluationDeptBusinessContentList) {
				if (evaluationDeptBusinessContent.getDeptId().equals(deptId)) {
					if (!"0".equals(evaluationDeptBusinessContent.getAuditStatusKp())) {
						b = false;
						msg = "数据审核状态未通过，请联系相关部门进行审核！";
						break;
					}
				}
			}
		}
		if (b) {
			return R.ok().data(b);
		} else {
			return R.error(msg);
		}
	}
}
