package com.ims.eval.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ims.common.utils.StringUtils;
import com.ims.eval.config.CustomException;
import com.ims.eval.entity.EvaluationDept;
import com.ims.eval.entity.EvaluationDeptBusinessContent;
import com.ims.eval.entity.EvaluationDeptBusinessPlan;
import com.ims.eval.entity.custom.Path;
import com.ims.eval.entity.dto.request.DeptDTO;
import com.ims.eval.entity.dto.request.EvaluationDeptBusinessPlanDTO;
import com.ims.eval.entity.dto.response.MyuserResDTO;
import com.ims.eval.entity.dto.result.R;
import com.ims.eval.feign.RemoteServiceBuilder;
import com.ims.eval.service.IEvaluationDeptBusinessContentService;
import com.ims.eval.service.IEvaluationDeptBusinessPlanService;
import com.ims.eval.service.IEvaluationDeptService;
import com.ims.eval.util.ExcelUtil;
import com.ims.eval.util.WordUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.io.InputStream;
import java.io.UnsupportedEncodingException;
import java.util.*;

/**
 * 本部部门业绩指标计划
 *
 * @author hlf
 * @date 2023/4/26 14:15
 * 文件说明：
 */
@Slf4j
@RestController
@RequestMapping("//evaluation-dept-plan")
public class DepartmentalPerformanceIndicatorPlanController {

	@Autowired
	private IEvaluationDeptBusinessPlanService evaluationDeptBusinessPlanService;

	@Autowired
	private IEvaluationDeptBusinessContentService evaluationDeptBusinessContentService;

	@Autowired
	private IEvaluationDeptService evaluationDeptService;

	@Autowired
	private HttpServletRequest request;

	@Autowired
	private RemoteServiceBuilder remoteServiceBuilder;

	/**
	 * 部门考评业务列表信息（分页）
	 *
	 * @param pageNum            当前记录起始索引
	 * @param pageSize           每页显示记录数
	 * @param responsibilityCode 业务编码
	 * @param des                业务简述
	 * @param appraisalYear      月度
	 * @param stage              流程状态
	 * @return 结果
	 */
	@GetMapping(value = "/list")
	public R list(
		@RequestParam(value = "pageNum") Integer pageNum,
		@RequestParam(value = "pageSize") Integer pageSize,
		@RequestParam(value = "deptId") String deptId,
		@RequestParam(value = "responsibilityCode", required = false) String responsibilityCode,
		@RequestParam(value = "des", required = false) String des,
		@RequestParam(value = "appraisalYear", required = false) String appraisalYear,
		@RequestParam(value = "stage", required = false) String stage) {
		IPage<EvaluationDeptBusinessPlan> list = evaluationDeptBusinessPlanService.listPage(pageNum, pageSize, deptId, responsibilityCode, des, appraisalYear, stage, request);
		return R.ok().data(list);
	}

	/**
	 * 部门考评业务信息
	 *
	 * @return 结果
	 */
	@GetMapping(value = "/listAll")
	public R listAll() {
		List<EvaluationDeptBusinessPlan> list = evaluationDeptBusinessPlanService.list();
		return R.ok().data(list);
	}

	/**
	 * 新增部门考评业务信息
	 *
	 * @param evaluationDeptBusinessPlan 部门考评业务实体
	 * @return 结果
	 */
	@PostMapping(value = "/save")
	public R addAll(@RequestBody EvaluationDeptBusinessPlan evaluationDeptBusinessPlan) {
		try {
			QueryWrapper<EvaluationDeptBusinessPlan> qw1 = new QueryWrapper<>();
			qw1.lambda().eq(EvaluationDeptBusinessPlan::getAppraisalYear, evaluationDeptBusinessPlan.getAppraisalYear());
			int x = evaluationDeptBusinessPlanService.count(qw1);
			QueryWrapper<EvaluationDept> qw2 = new QueryWrapper<>();
			qw2.lambda().eq(EvaluationDept::getYjzbjhType, "1");
			int count = evaluationDeptService.count(qw2);
			if (x >= count) {
				return R.error(evaluationDeptBusinessPlan.getAppraisalYear() + "年度业绩指标已下达完成！");
			}
			boolean b = evaluationDeptBusinessPlanService.save(evaluationDeptBusinessPlan);
			if (b) {
				return R.ok().data(b);
			} else {
				return R.error("保存失败！");
			}
		} catch (CustomException e) {
			return R.customError(e.getMessage()).data("失败！");
		}
	}

	/**
	 * 校验考评部门
	 *
	 * @return 结果
	 */
	@GetMapping(value = "/verifyDept")
	public R verifyDept() {
		QueryWrapper<EvaluationDept> qw = new QueryWrapper<>();
		qw.lambda().eq(EvaluationDept::getYjzbjhType, "1");
		List<EvaluationDept> list = evaluationDeptService.list(qw);
		int count = list.size();
		return R.ok().data(count);
	}

	/**
	 * 修改部门考评业务信息
	 *
	 * @param evaluationDeptBusinessPlan 部门考评业务实体
	 * @return 结果
	 */
	@PostMapping(value = "/modify")
	public R modify(@RequestBody EvaluationDeptBusinessPlan evaluationDeptBusinessPlan) {
		try {
			boolean b = evaluationDeptBusinessPlanService.updateById(evaluationDeptBusinessPlan);
			if (b) {
				return R.ok().data(b);
			} else {
				return R.error("修改失败！");
			}
		} catch (CustomException e) {
			return R.customError(e.getMessage()).data("失败！");
		}
	}

	/**
	 * 批量删除部门考评业务信息
	 *
	 * @param ids 主键s
	 * @return 结果
	 */
	@PostMapping(value = "/removeAll/{ids}")
	public R deleteAll(@PathVariable("ids") String ids) {
		try {
			String[] strings = ids.split(",");
			boolean b = evaluationDeptBusinessPlanService.removeByIds(Arrays.asList(strings));
			if (b) {
				return R.ok().data(b);
			} else {
				return R.error("删除失败，流程已启动或流程未结束！");
			}
		} catch (CustomException e) {
			return R.customError(e.getMessage()).data("失败！");
		}
	}

	/**
	 * 详情-头部信息
	 *
	 * @param id 业务主键
	 * @return 结果
	 */
	@GetMapping(value = "/detailsHead/{id}")
	public R detailsHead(@PathVariable("id") String id) {
		EvaluationDeptBusinessPlan evaluationDeptBusinessPlan = evaluationDeptBusinessPlanService.getById(id);
		return R.ok().data(evaluationDeptBusinessPlan);
	}

	/**
	 * 详情
	 *
	 * @param id 业务主键
	 * @return 结果
	 */
	@GetMapping(value = "/details/{id}/{deptId}/{deptName}")
	public R details(@PathVariable("id") String id, @PathVariable("deptId") String deptId, @PathVariable("deptName") String deptName) {
		String code = request.getHeader("code");
		JSONObject json = remoteServiceBuilder.getGatewayUrl().getSysUser(code);
		MyuserResDTO user = JSONObject.parseObject(json.getJSONObject("data").toJSONString(), MyuserResDTO.class);
		user.getDeptOrg().getType();
		if ("150".equals(user.getDeptOrg().getType())) {
			deptId = user.getDeptOrg().getParentId();
		}
		List<EvaluationDeptBusinessContent> list = evaluationDeptBusinessContentService.detailsList(id, deptId, deptName);
		for (EvaluationDeptBusinessContent evaluationDeptBusinessContent : list) {
			if (!"23031009".equals(evaluationDeptBusinessContent.getCreateDept())) {//是否组织人事部添加的数据
				evaluationDeptBusinessContent.setDataPermission("1");
			} else {
				if ("23031009".equals(deptId)) {//组织人事部
					evaluationDeptBusinessContent.setDataPermission("1");
				} else {
					evaluationDeptBusinessContent.setDataPermission("-1");
				}
			}
		}
		return R.ok().data(list);
	}

	/**
	 * 详情-修改/新增
	 *
	 * @param evaluationDeptBusinessContentList 修改内容
	 * @return 结果
	 */
	@PostMapping(value = "/update")
	public R update(@RequestBody List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList) {
		try {
			boolean b = evaluationDeptBusinessContentService.saveOrUpdateBatch(evaluationDeptBusinessContentList);
			if (b) {
				return R.ok().data(b);
			} else {
				return R.error("新增/修改失败，指标名称重复！");
			}
		} catch (CustomException e) {
			return R.customError(e.getMessage()).data("失败！");
		} catch (UnsupportedEncodingException e) {
			throw new RuntimeException(e);
		}
	}

	/**
	 * 详情-删除
	 *
	 * @param id 主键
	 * @return 结果
	 */
	@PostMapping(value = "/delete/{id}/{deptId}")
	public R delete(@PathVariable String id, @PathVariable String deptId) {
		try {
			EvaluationDeptBusinessContent evaluationDeptBusinessContent = evaluationDeptBusinessContentService.getById(id);
			if (null != evaluationDeptBusinessContent) {
				if ("23031009".equals(evaluationDeptBusinessContent.getCreateDept())) {//组织人事部添加
					if (!"23031009".equals(deptId)) {//非组织人事部
						return R.error("没有删除权限，删除失败！");
					}
				}
			}
			boolean b = evaluationDeptBusinessContentService.removeById(id);
			if (b) {
				return R.ok().data(b);
			} else {
				return R.error("删除失败！");
			}
		} catch (CustomException e) {
			return R.customError(e.getMessage()).data("失败！");
		}
	}

	/**
	 * 详情-部门数据
	 *
	 * @param deptId 当前登录人部门主键
	 * @return 结果
	 */
	@GetMapping(value = "/detailDeptData")
	public R detailDeptData(@RequestParam(value = "deptId") String deptId) {
		List<DeptDTO> deptList = new ArrayList<>();
		QueryWrapper<EvaluationDept> qw = new QueryWrapper<>();
		qw.lambda().eq(EvaluationDept::getYjzbjhType, "1");
		qw.lambda().orderByAsc(EvaluationDept::getSerialNumber);
		List<EvaluationDept> evaluationDeptList = evaluationDeptService.list(qw);
		for (EvaluationDept evaluationDept : evaluationDeptList) {
			if ("23031009".equals(deptId)) {//组织人事部
				DeptDTO dept = new DeptDTO();
				dept.setDeptId(evaluationDept.getDeptId());
				dept.setDeptName(evaluationDept.getDeptName());
				deptList.add(dept);
			} else {
				String code = request.getHeader("code");
				JSONObject json = remoteServiceBuilder.getGatewayUrl().getSysUser(code);
				MyuserResDTO user = JSONObject.parseObject(json.getJSONObject("data").toJSONString(), MyuserResDTO.class);
				user.getDeptOrg().getType();
				if ("150".equals(user.getDeptOrg().getType())) {
					deptId = user.getDeptOrg().getParentId();
				}
				if (deptId.equals(evaluationDept.getDeptId())) {
					DeptDTO dept = new DeptDTO();
					dept.setDeptId(evaluationDept.getDeptId());
					dept.setDeptName(evaluationDept.getDeptName());
					deptList.add(dept);
				}
			}
		}
		return R.ok().data(deptList);
	}

	/**
	 * 导入
	 *
	 * @param file 文件
	 * @return 结果
	 */
	@PostMapping(value = "/import")
	public R importData(@RequestParam("file") MultipartFile file, @RequestParam("id") String id) {
		if (!file.isEmpty()) {
			try {
				//获取原始的文件名
				String originalFilename = file.getOriginalFilename();
				//获取文件类型
				String fileType = originalFilename.substring(originalFilename.lastIndexOf(".") + 1, originalFilename.length());
				//默认从第一行开始读取
				int startRows = 1;
				//获取输入流
				InputStream is = file.getInputStream();
				EvaluationDeptBusinessPlan evaluationDeptBusinessPlan = evaluationDeptBusinessPlanService.getById(id);
				List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = new ArrayList<>();
				//Excel导入导出的单元类
				List<String[]> strings = ExcelUtil.readData(fileType, startRows, true, is);
				//遍历Excel表每一行的数据
				for (String[] str : strings) {
					EvaluationDeptBusinessContent evaluationDeptBusinessContent = new EvaluationDeptBusinessContent();
					evaluationDeptBusinessContent.setBusinessPlanId(id);
					if (null == evaluationDeptBusinessPlan.getDeptId() && null == evaluationDeptBusinessPlan.getDeptName()) {
						evaluationDeptBusinessContent.setDeptId(str[0]);
						evaluationDeptBusinessContent.setDeptName(str[1]);
					} else {
						evaluationDeptBusinessContent.setDeptId(evaluationDeptBusinessPlan.getDeptId());
						evaluationDeptBusinessContent.setDeptName(evaluationDeptBusinessPlan.getDeptName());
					}
					evaluationDeptBusinessContent.setSerialNumber(Integer.valueOf(str[2]));
					evaluationDeptBusinessContent.setTargetName(str[3]);
					evaluationDeptBusinessContent.setTargetValue(str[4]);
					evaluationDeptBusinessContent.setEvaluationCriteria(str[5]);
					evaluationDeptBusinessContent.setBaseScore(str[6]);
					evaluationDeptBusinessContentList.add(evaluationDeptBusinessContent);
				}
				boolean b = evaluationDeptBusinessContentService.importPlanDataList(evaluationDeptBusinessContentList);
				if (b) {
					return R.ok().data(b);
				} else {
					return R.error("导入失败！");
				}
			} catch (Exception e) {
				log.error("错误", e);
				return R.customError(e.getMessage()).data("失败！");
			}
		}
		return R.error("上传文件为空！");
	}

	/**
	 * 修改状态
	 *
	 * @param id    主键
	 * @param stage 状态
	 * @return 结果
	 */
	@PostMapping(value = "/targetStart")
	public R targetStart(@RequestParam(value = "id") String id,
						 @RequestParam(value = "stage") String stage) {
		try {
			EvaluationDeptBusinessPlan evaluationDeptBusinessPlan = evaluationDeptBusinessPlanService.getById(id);
			evaluationDeptBusinessPlan.setStage(stage);
			boolean b = evaluationDeptBusinessPlanService.updateById(evaluationDeptBusinessPlan);
			if (b) {
				return R.ok().data(b);
			} else {
				return R.error("失败！");
			}
		} catch (CustomException e) {
			return R.customError(e.getMessage()).data("失败！");
		}
	}

	/**
	 * 生成报表
	 *
	 * @return 结果
	 */
	@GetMapping(value = "/generateReport/{id}")
	public R generateReport(@PathVariable("id") String id) throws Exception {
		Map<String, Object> dataMap = new HashMap<>();
		List<DeptDTO> deptList = new ArrayList<>();
		String fileName;
		EvaluationDeptBusinessPlan evaluationDeptBusinessPlan = evaluationDeptBusinessPlanService.getById(id);
		if (null == evaluationDeptBusinessPlan.getDeptId() && null == evaluationDeptBusinessPlan.getDeptName()) {
			QueryWrapper<EvaluationDept> qw = new QueryWrapper<>();
			qw.lambda().eq(EvaluationDept::getYjzbjhType, "1");
			qw.lambda().orderByAsc(EvaluationDept::getSerialNumber);
			List<EvaluationDept> evaluationDeptList = evaluationDeptService.list(qw);
			for (EvaluationDept evaluationDept : evaluationDeptList) {
				DeptDTO dept = new DeptDTO();
				dept.setDeptId(evaluationDept.getDeptId());
				dept.setDeptName(evaluationDept.getDeptName());
				List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = evaluationDeptBusinessContentService.selectEvaluationDeptBusinessContentListByBusinessPlanId(id, evaluationDept.getDeptId());
				if (evaluationDeptBusinessContentList.size() > 0) {
					dept.setEvaluationDeptBusinessContent(evaluationDeptBusinessContentList.get(0));
					if (evaluationDeptBusinessContentList.size() > 1) {
						evaluationDeptBusinessContentList.remove(0);
						dept.setList(evaluationDeptBusinessContentList);
					}
				}
				deptList.add(dept);
			}
			fileName = evaluationDeptBusinessPlan.getAppraisalYear() + "年度经营业绩指标计划.doc";
		} else {
			DeptDTO dept = new DeptDTO();
			dept.setDeptId(evaluationDeptBusinessPlan.getDeptId());
			dept.setDeptName(evaluationDeptBusinessPlan.getDeptName());
			List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = evaluationDeptBusinessContentService.selectEvaluationDeptBusinessContentListByBusinessPlanId(id, evaluationDeptBusinessPlan.getDeptId());
			if (evaluationDeptBusinessContentList.size() > 0) {
				dept.setEvaluationDeptBusinessContent(evaluationDeptBusinessContentList.get(0));
				if (evaluationDeptBusinessContentList.size() > 1) {
					evaluationDeptBusinessContentList.remove(0);
					dept.setList(evaluationDeptBusinessContentList);
				}
			}
			deptList.add(dept);
			fileName = evaluationDeptBusinessPlan.getDeptName() + evaluationDeptBusinessPlan.getAppraisalYear() + "年度经营业绩指标计划.doc";
		}
		dataMap.put("appraisalYear", evaluationDeptBusinessPlan.getAppraisalYear());
		dataMap.put("list", deptList);
		WordUtil.generateWord(dataMap, "template_dbkp_zbjh.ftl", Path.getStatementPath(), fileName);
		return R.ok().data(fileName);
	}

	/**
	 * 统计汇总数据
	 *
	 * @param year 年度
	 */
	@GetMapping(value = "/statisticalSummary")
	public R statisticalSummary(@RequestParam(value = "year") String year) {
		List<EvaluationDeptBusinessPlanDTO> dtoList = new ArrayList<>();
		List<EvaluationDeptBusinessPlan> evaluationDeptBusinessPlanList = evaluationDeptBusinessPlanService.selectEvaluationDeptBusinessPlanByYear(year);
		if ("2023".equals(year)) {
			QueryWrapper<EvaluationDept> qw = new QueryWrapper<>();
			qw.lambda().eq(EvaluationDept::getYjzbjhType, "1");
			qw.lambda().orderByAsc(EvaluationDept::getSerialNumber);
			List<EvaluationDept> evaluationDeptList = evaluationDeptService.list(qw);
			for (EvaluationDept evaluationDept : evaluationDeptList) {
				if (evaluationDeptBusinessPlanList.size() > 0) {
					List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = evaluationDeptBusinessContentService.selectEvaluationDeptBusinessContentListByBusinessPlanId(evaluationDeptBusinessPlanList.get(0).getId(), evaluationDept.getDeptId());
					for (EvaluationDeptBusinessContent evaluationDeptBusinessContent : evaluationDeptBusinessContentList) {
						EvaluationDeptBusinessPlanDTO dto = new EvaluationDeptBusinessPlanDTO();
						dto.setDeptName(evaluationDept.getDeptName());
						dto.setSerialNumber(evaluationDeptBusinessContent.getSerialNumber());
						dto.setTargetName(evaluationDeptBusinessContent.getTargetName());
						dto.setTargetValue(evaluationDeptBusinessContent.getTargetValue());
						dto.setBaseScore(evaluationDeptBusinessContent.getBaseScore());
						dto.setEvaluationCriteria(evaluationDeptBusinessContent.getEvaluationCriteria());
						dtoList.add(dto);
					}
				}
			}
		} else {
			for (EvaluationDeptBusinessPlan evaluationDeptBusinessPlan : evaluationDeptBusinessPlanList) {
				List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = evaluationDeptBusinessContentService.selectEvaluationDeptBusinessContentListByBusinessPlanId(evaluationDeptBusinessPlan.getId(), evaluationDeptBusinessPlan.getDeptId());
				for (EvaluationDeptBusinessContent evaluationDeptBusinessContent : evaluationDeptBusinessContentList) {
					EvaluationDeptBusinessPlanDTO dto = new EvaluationDeptBusinessPlanDTO();
					dto.setDeptName(evaluationDeptBusinessPlan.getDeptName());
					dto.setSerialNumber(evaluationDeptBusinessContent.getSerialNumber());
					dto.setTargetName(evaluationDeptBusinessContent.getTargetName());
					dto.setTargetValue(evaluationDeptBusinessContent.getTargetValue());
					dto.setBaseScore(evaluationDeptBusinessContent.getBaseScore());
					dto.setEvaluationCriteria(evaluationDeptBusinessContent.getEvaluationCriteria());
					dtoList.add(dto);
				}
			}
		}
		return R.ok().data(dtoList);
	}

	/**
	 * 生成汇总报表
	 *
	 * @return 结果
	 */
	@GetMapping(value = "/summaryReport/{year}")
	public R summaryReport(@PathVariable("year") String year) throws Exception {
		Map<String, Object> dataMap = new HashMap<>();
		List<EvaluationDeptBusinessPlan> evaluationDeptBusinessPlanList = evaluationDeptBusinessPlanService.selectEvaluationDeptBusinessPlanByYear(year);
		List<DeptDTO> deptList = new ArrayList<>();
		if ("2023".equals(year)) {
			QueryWrapper<EvaluationDept> qw = new QueryWrapper<>();
			qw.lambda().eq(EvaluationDept::getYjzbjhType, "1");
			qw.lambda().orderByAsc(EvaluationDept::getSerialNumber);
			List<EvaluationDept> evaluationDeptList = evaluationDeptService.list(qw);
			for (EvaluationDept evaluationDept : evaluationDeptList) {
				if (evaluationDeptBusinessPlanList.size() > 0) {
					DeptDTO dept = new DeptDTO();
					dept.setDeptId(evaluationDept.getDeptId());
					dept.setDeptName(evaluationDept.getDeptName());
					List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = evaluationDeptBusinessContentService.selectEvaluationDeptBusinessContentListByBusinessPlanId(evaluationDeptBusinessPlanList.get(0).getId(), evaluationDept.getDeptId());
					if (evaluationDeptBusinessContentList.size() > 0) {
						dept.setEvaluationDeptBusinessContent(evaluationDeptBusinessContentList.get(0));
						if (evaluationDeptBusinessContentList.size() > 1) {
							evaluationDeptBusinessContentList.remove(0);
							dept.setList(evaluationDeptBusinessContentList);
						}
					}
					deptList.add(dept);
				}
			}
		} else {
			for (EvaluationDeptBusinessPlan evaluationDeptBusinessPlan : evaluationDeptBusinessPlanList) {
				DeptDTO dept = new DeptDTO();
				dept.setDeptId(evaluationDeptBusinessPlan.getDeptId());
				dept.setDeptName(evaluationDeptBusinessPlan.getDeptName());
				List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = evaluationDeptBusinessContentService.selectEvaluationDeptBusinessContentListByBusinessPlanId(evaluationDeptBusinessPlan.getId(), evaluationDeptBusinessPlan.getDeptId());
				if (evaluationDeptBusinessContentList.size() > 0) {
					dept.setEvaluationDeptBusinessContent(evaluationDeptBusinessContentList.get(0));
					if (evaluationDeptBusinessContentList.size() > 1) {
						evaluationDeptBusinessContentList.remove(0);
						dept.setList(evaluationDeptBusinessContentList);
					}
				}
				deptList.add(dept);
			}
		}
		dataMap.put("appraisalYear", year);
		dataMap.put("list", deptList);
		String fileName = year + "年度经营业绩指标计划.doc";
		WordUtil.generateWord(dataMap, "template_dbkp_zbjh.ftl", Path.getStatementPath(), fileName);
		return R.ok().data(fileName);
	}

	/**
	 * 校验审核状态
	 *
	 * @param id 主键
	 * @return 结果
	 */
	@GetMapping(value = "/checkAuditStatus/{id}/{deptId}")
	public R checkAuditStatus(@PathVariable String id, @PathVariable String deptId) {
		boolean b = true;
		String msg = "";
		QueryWrapper<EvaluationDeptBusinessContent> qw = new QueryWrapper<>();
		if (StringUtils.isNotEmpty(id)) {
			qw.lambda().eq(EvaluationDeptBusinessContent::getBusinessPlanId, id);
		}
		List<EvaluationDeptBusinessContent> evaluationDeptBusinessContentList = evaluationDeptBusinessContentService.list(qw);
		if ("23031009".equals(deptId)) {//组织人事部
			for (EvaluationDeptBusinessContent evaluationDeptBusinessContent : evaluationDeptBusinessContentList) {
				if (!"0".equals(evaluationDeptBusinessContent.getAuditStatus())) {
					b = false;
					msg = "数据审核状态未通过！";
					break;
				}
			}
		} else {
			for (EvaluationDeptBusinessContent evaluationDeptBusinessContent : evaluationDeptBusinessContentList) {
				if (evaluationDeptBusinessContent.getDeptId().equals(deptId)) {
					if (!"0".equals(evaluationDeptBusinessContent.getAuditStatus())) {
						b = false;
						msg = "数据审核状态未通过，请联系相关部门进行审核！";
						break;
					}
				}
			}
		}
		if (b) {
			return R.ok().data(b);
		} else {
			return R.error(msg);
		}
	}
}
