package com.ims.eval.service.impl;

import cn.hutool.core.convert.Convert;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ims.common.utils.StringUtils;
import com.ims.eval.config.ImaConfig;
import com.ims.eval.dao.DeptAssessmentDeclarationMapper;
import com.ims.eval.entity.DeptAssessmentDeclaration;
import com.ims.eval.entity.DeptAssessmentDeclarationContent;
import com.ims.eval.entity.EvaluationDept;
import com.ims.eval.entity.EvaluationDeptRating;
import com.ims.eval.entity.dto.request.UserDTO;
import com.ims.eval.entity.dto.response.MyuserResDTO;
import com.ims.eval.entity.dto.result.ResultInfo;
import com.ims.eval.feign.RemoteServiceBuilder;
import com.ims.eval.service.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpMethod;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.List;

/**
 * @author hlf
 * @date 2023/5/29 15:01
 * 文件说明：
 */
@Service
@Slf4j
public class DeptAssessmentDeclarationServiceImpl extends ServiceImpl<DeptAssessmentDeclarationMapper, DeptAssessmentDeclaration> implements IDeptAssessmentDeclarationService {

	@Autowired
	private IDeptAssessmentDeclarationContentService deptAssessmentDeclarationContentService;

	@Autowired
	private IDeptAssessmentDeclarationCompleteService deptAssessmentDeclarationCompleteService;

	@Autowired
	private IUserService userService;

	@Autowired
	private IEvaluationDeptService evaluationDeptService;

	@Autowired
	private IEvaluationDeptRatingService evaluationDeptRatingService;

	@Autowired
	private RestTemplate restTemplate;

	@Autowired
	private ImaConfig imaConfig;

	@Autowired
	private RemoteServiceBuilder remoteServiceBuilder;

	@Override
	public IPage<DeptAssessmentDeclaration> listPage(Integer pageNum, Integer pageSize, String deptId, String orderNumber, String deptName, Integer annual, Integer declarationMonth,HttpServletRequest request) {


		String code = request.getHeader("code");
		JSONObject json = remoteServiceBuilder.getGatewayUrl().getSysUser(code);
		MyuserResDTO user = JSONObject.parseObject(json.getJSONObject("data").toJSONString(), MyuserResDTO.class);

		user.getDeptOrg().getType();

		if("150".equals(user.getDeptOrg().getType())){
			deptId = user.getDeptOrg().getParentId();
		}
		if ("23031009".equals(deptId)) {//组织人事部
			deptId = "";
		}


		if (null == pageNum || null == pageSize) {
			throw new RuntimeException("分页参数为空");
		}
		//构造分页构造器
		Page<DeptAssessmentDeclaration> page = new Page<>(pageNum, pageSize);
		return baseMapper.selectListPage(page, deptId, orderNumber, deptName, annual, declarationMonth);
	}

	@Override
	public boolean save(DeptAssessmentDeclaration deptAssessmentDeclaration, HttpServletRequest request) {
		QueryWrapper<DeptAssessmentDeclaration> qw = new QueryWrapper<>();
		if (null != deptAssessmentDeclaration.getAnnual()) {
			qw.lambda().eq(DeptAssessmentDeclaration::getAnnual, deptAssessmentDeclaration.getAnnual());
		}
		if (null != deptAssessmentDeclaration.getDeclarationMonth()) {
			qw.lambda().eq(DeptAssessmentDeclaration::getDeclarationMonth, deptAssessmentDeclaration.getDeclarationMonth());
		}
		int count = super.count(qw);
		String id = Convert.toStr(IdUtil.getSnowflake(1, 1).nextId());
		deptAssessmentDeclaration.setId(id);
		deptAssessmentDeclaration.setOrderNumber("KHSB_GDDL_" + deptAssessmentDeclaration.getAnnual() + "_" + StringUtils.addZeroForStr(String.valueOf(deptAssessmentDeclaration.getDeclarationMonth()), 2, "l") + StringUtils.addZeroForStr(String.valueOf(count + 1), 2, "l"));
		deptAssessmentDeclaration.setRatingGrade(deptAssessmentDeclaration.getDeclarationLevel());
		deptAssessmentDeclaration.setStage("流程未启动");
		deptAssessmentDeclaration.setCreateTime(DateUtil.date());

		deptAssessmentDeclaration.setDeptLeaderId("0");
		deptAssessmentDeclaration.setDeptLeaderNo("0");
		deptAssessmentDeclaration.setDeptLeaderName("0");

		deptAssessmentDeclaration.setSeconderId("0");
		deptAssessmentDeclaration.setSeconderNo("0");
		deptAssessmentDeclaration.setSeconderName("0");

		List<DeptAssessmentDeclarationContent> deptAssessmentDeclarationContentList = new ArrayList<>();
		QueryWrapper<EvaluationDept> deptQw = new QueryWrapper<>();
		if (StringUtils.isNotEmpty(deptAssessmentDeclaration.getDeptId())) {
			deptQw.lambda().eq(EvaluationDept::getDeptId, deptAssessmentDeclaration.getDeptId());
		}
		EvaluationDept evaluationDept = evaluationDeptService.getOne(deptQw);
		if (null != evaluationDept) {
			if ("".equals(evaluationDept.getParentId()) || null == evaluationDept.getParentId()) {//父级部门为空 表示当前为父级
				List<UserDTO> secondaryList = new ArrayList<>();
				QueryWrapper<EvaluationDept> secondaryDeptQw = new QueryWrapper<>();
				if (StringUtils.isNotEmpty(evaluationDept.getDeptId())) {
					secondaryDeptQw.lambda().eq(EvaluationDept::getParentId, evaluationDept.getDeptId());
				}
				List<EvaluationDept> evaluationDeptList = evaluationDeptService.list(secondaryDeptQw);
				for (EvaluationDept obj : evaluationDeptList) {
					JSONObject jsonArr = userService.pageList(1, 500, obj.getDeptId(), "", "", "", "", "", request);
					JSONObject jsonArr1 = (JSONObject) jsonArr.get("data");
					JSONArray array = JSONUtil.parseArray(jsonArr1.get("records"));
					List<UserDTO> userList = JSONUtil.toList(array, UserDTO.class);
					secondaryList.addAll(userList);
				}
				JSONObject jsonArr = userService.pageList(1, 500, deptAssessmentDeclaration.getDeptId(), "", "", "", "", "", request);
				JSONObject jsonArr1 = (JSONObject) jsonArr.get("data");
				JSONArray array = JSONUtil.parseArray(jsonArr1.get("records"));
				List<UserDTO> userList = JSONUtil.toList(array, UserDTO.class);
				userList.removeAll(secondaryList);
				for (int i = 0; i < userList.size(); i++) {
					UserDTO user = userList.get(i);
					if (!"".equals(user.getNo()) && null != user.getNo()) {
						DeptAssessmentDeclarationContent deptAssessmentDeclarationContent = new DeptAssessmentDeclarationContent();
						deptAssessmentDeclarationContent.setAssessmentDeclarationId(id);
						deptAssessmentDeclarationContent.setSerialNumber(i + 1);
						deptAssessmentDeclarationContent.setEmployeeId(user.getId());
						deptAssessmentDeclarationContent.setEmployeeNo(user.getNo());
						deptAssessmentDeclarationContent.setEmployeeName(user.getName());
						deptAssessmentDeclarationContent.setSuggestedValue("1");
						deptAssessmentDeclarationContentList.add(deptAssessmentDeclarationContent);
					}
				}
			} else {//子级部门
				JSONObject jsonArr = userService.pageList(1, 500, deptAssessmentDeclaration.getDeptId(), "", "", "", "", "", request);
				JSONObject jsonArr1 = (JSONObject) jsonArr.get("data");
				JSONArray array = JSONUtil.parseArray(jsonArr1.get("records"));
				List<UserDTO> userList = JSONUtil.toList(array, UserDTO.class);
				for (int i = 0; i < userList.size(); i++) {
					UserDTO user = userList.get(i);
					if (!"".equals(user.getNo()) && null != user.getNo()) {
						DeptAssessmentDeclarationContent deptAssessmentDeclarationContent = new DeptAssessmentDeclarationContent();
						deptAssessmentDeclarationContent.setAssessmentDeclarationId(id);
						deptAssessmentDeclarationContent.setSerialNumber(i + 1);
						deptAssessmentDeclarationContent.setEmployeeId(user.getId());
						deptAssessmentDeclarationContent.setEmployeeNo(user.getNo());
						deptAssessmentDeclarationContent.setEmployeeName(user.getName());
						deptAssessmentDeclarationContent.setSuggestedValue("1");
						deptAssessmentDeclarationContentList.add(deptAssessmentDeclarationContent);
					}
				}
			}
		}
		boolean b = super.save(deptAssessmentDeclaration);
		if (b) {
			b = deptAssessmentDeclarationContentService.saveBatch(deptAssessmentDeclarationContentList);
		}
		return b;
	}

	@Override
	public boolean removeByIds(List<String> ids) {
		for (String id : ids) {
			DeptAssessmentDeclaration deptAssessmentDeclaration = super.getById(id);
			if ("流程未启动".equals(deptAssessmentDeclaration.getStage())) {
				deptAssessmentDeclarationContentService.removeByAssessmentDeclarationId(id);
				deptAssessmentDeclarationCompleteService.removeByAssessmentDeclarationId(id);
				super.removeById(id);
			}
		}
		return true;
	}

	@Override
	public boolean editState(String id, String state, String instId, String destination) {
		DeptAssessmentDeclaration deptAssessmentDeclaration = baseMapper.selectById(id);
		if (StringUtils.isNotEmpty(state)) {
			if ("组织人事部审核".equals(state)) {
				state = "流程已结束";
			}
			deptAssessmentDeclaration.setStage(state);
		}
		if (StringUtils.isNotEmpty(instId)) {
			deptAssessmentDeclaration.setInstId(instId);
		}
		if (StringUtils.isNotEmpty(destination)) {
			if ("EndNoneEvent1".equals(destination)) {
				deptAssessmentDeclaration.setStage("流程已结束");
			}
		}
		baseMapper.updateById(deptAssessmentDeclaration);
		if ("流程已结束".equals(deptAssessmentDeclaration.getStage())) {
			QueryWrapper<EvaluationDeptRating> qw = new QueryWrapper<>();
			if (StringUtils.isNotEmpty(deptAssessmentDeclaration.getDeptId())) {
				qw.lambda().eq(EvaluationDeptRating::getDeptId, deptAssessmentDeclaration.getDeptId());
			}
			if (null != deptAssessmentDeclaration.getAnnual()) {
				qw.lambda().eq(EvaluationDeptRating::getAnnual, String.valueOf(deptAssessmentDeclaration.getAnnual()));
			}
			EvaluationDeptRating evaluationDeptRating = evaluationDeptRatingService.getOne(qw);
			if (null != evaluationDeptRating) {
				insertContent(deptAssessmentDeclaration, evaluationDeptRating);
				evaluationDeptRatingService.updateById(evaluationDeptRating);
			} else {
				EvaluationDeptRating obj = new EvaluationDeptRating();
				insertContent(deptAssessmentDeclaration, obj);
				evaluationDeptRatingService.save(obj);
			}
		}
		return true;
	}

	@Override
	public Object processInformation(String instId, HttpServletRequest request) {
		MultiValueMap<String, String> headers = new LinkedMultiValueMap<>();
		headers.add("Blade-Auth", "bearer " + request.getHeader("Blade-Auth"));
		HttpEntity<LinkedMultiValueMap<String, Object>> param = new HttpEntity<>(null, headers);
		ResponseEntity<String> responseEntity2 = restTemplate.exchange(imaConfig.getFlowUrl() + "bpm/instance/getOpinion?instId={1}", HttpMethod.GET, param, String.class, instId);
		log.info("\n code:{}\n header:{}\n body:{}\n", responseEntity2.getStatusCodeValue(), responseEntity2.getHeaders(), responseEntity2.getBody());
		if (200 == responseEntity2.getStatusCodeValue()) {
			ResultInfo resultInfo = JSON.parseObject(responseEntity2.getBody(), ResultInfo.class);
			return resultInfo.getData();
		}
		return null;
	}

	private static void insertContent(DeptAssessmentDeclaration deptAssessmentDeclaration, EvaluationDeptRating evaluationDeptRating) {
		if (1 == deptAssessmentDeclaration.getDeclarationMonth()) {
			evaluationDeptRating.setJan(deptAssessmentDeclaration.getRatingGrade());
			evaluationDeptRating.setJanContent(deptAssessmentDeclaration.getDeclarationReason());
		} else if (2 == deptAssessmentDeclaration.getDeclarationMonth()) {
			evaluationDeptRating.setFeb(deptAssessmentDeclaration.getRatingGrade());
			evaluationDeptRating.setFebContent(deptAssessmentDeclaration.getDeclarationReason());
		} else if (3 == deptAssessmentDeclaration.getDeclarationMonth()) {
			evaluationDeptRating.setMar(deptAssessmentDeclaration.getRatingGrade());
			evaluationDeptRating.setMarContent(deptAssessmentDeclaration.getDeclarationReason());
		} else if (4 == deptAssessmentDeclaration.getDeclarationMonth()) {
			evaluationDeptRating.setApr(deptAssessmentDeclaration.getRatingGrade());
			evaluationDeptRating.setAprContent(deptAssessmentDeclaration.getDeclarationReason());
		} else if (5 == deptAssessmentDeclaration.getDeclarationMonth()) {
			evaluationDeptRating.setMay(deptAssessmentDeclaration.getRatingGrade());
			evaluationDeptRating.setMayContent(deptAssessmentDeclaration.getDeclarationReason());
		} else if (6 == deptAssessmentDeclaration.getDeclarationMonth()) {
			evaluationDeptRating.setJun(deptAssessmentDeclaration.getRatingGrade());
			evaluationDeptRating.setJunContent(deptAssessmentDeclaration.getDeclarationReason());
		} else if (7 == deptAssessmentDeclaration.getDeclarationMonth()) {
			evaluationDeptRating.setJul(deptAssessmentDeclaration.getRatingGrade());
			evaluationDeptRating.setJulContent(deptAssessmentDeclaration.getDeclarationReason());
		} else if (8 == deptAssessmentDeclaration.getDeclarationMonth()) {
			evaluationDeptRating.setAug(deptAssessmentDeclaration.getRatingGrade());
			evaluationDeptRating.setAugContent(deptAssessmentDeclaration.getDeclarationReason());
		} else if (9 == deptAssessmentDeclaration.getDeclarationMonth()) {
			evaluationDeptRating.setSep(deptAssessmentDeclaration.getRatingGrade());
			evaluationDeptRating.setSepContent(deptAssessmentDeclaration.getDeclarationReason());
		} else if (10 == deptAssessmentDeclaration.getDeclarationMonth()) {
			evaluationDeptRating.setOct(deptAssessmentDeclaration.getRatingGrade());
			evaluationDeptRating.setOctContent(deptAssessmentDeclaration.getDeclarationReason());
		} else if (11 == deptAssessmentDeclaration.getDeclarationMonth()) {
			evaluationDeptRating.setNov(deptAssessmentDeclaration.getRatingGrade());
			evaluationDeptRating.setNovContent(deptAssessmentDeclaration.getDeclarationReason());
		} else if (12 == deptAssessmentDeclaration.getDeclarationMonth()) {
			evaluationDeptRating.setDece(deptAssessmentDeclaration.getRatingGrade());
			evaluationDeptRating.setDeceContent(deptAssessmentDeclaration.getDeclarationReason());
		}
	}
}
